@@ -163,7 +163,9 @@ class Config(object):
             return 'python3.6'
         elif (major, minor) <= (3, 7):
             return 'python3.7'
-        return 'python3.8'
+        elif (major, minor) <= (3, 8):
+            return 'python3.8'
+        return 'python3.9'
 
     @property
     def layers(self):
@@ -329,6 +331,13 @@ class Config(object):
                                   varies_per_chalice_stage=True,
                                   varies_per_function=True)
 
+    @property
+    def xray_enabled(self):
+        # type: () -> bool
+        return self._chain_lookup('xray',
+                                  varies_per_chalice_stage=True,
+                                  varies_per_function=True)
+
     @property
     def environment_variables(self):
         # type: () -> Dict[str, str]
